@@ -439,6 +439,9 @@ struct WrapperConfig {
     int     ntShutdownWaitHint;     /* Delay in seconds requested by the Wrapper when it reports a STOPPING or PAUSING status to the service controler. */
     int     ntStartupWaitHint;      /* Delay in seconds requested by the Wrapper when it reports a STARTING or RESUMING status to the service controler. */
     int     threadDumpControlCode;  /* Control code which can be used to trigger a thread dump. */
+    BOOL    DEPApiAvailable;        /* TRUE if the DEP API is available in Kernel32, false otherwise. */
+    BOOL    DEPStatus;              /* TRUE if DEP has been enabled. */
+    DWORD   DEPError;               /* Error code returned when failing to enable DEP. */
 #else /* UNIX */
     int     daemonize;              /* TRUE if the process  should be spawned as a daemon process on launch. */
     int     signalHUPMode;          /* Controls what happens when the Wrapper receives a HUP signal. */
@@ -474,6 +477,7 @@ struct WrapperConfig {
 #else
     int     signalInterruptTrapped; /* SIGINT was trapped. */
     int     signalQuitTrapped;      /* SIGQUIT was trapped. */
+    int     signalQuitKernel;       /* SIGQUIT was originated by the kernel. */
     int     signalChildTrapped;     /* SIGCHLD was trapped. */
     int     signalTermTrapped;      /* SIGTERM was trapped. */
     int     signalHUPTrapped;       /* SIGHUP was trapped. */
@@ -797,7 +801,7 @@ extern void wrapperCheckConsoleWindows();
 /**
  *   checks the digital Signature of the binary and reports the result.
  */
-extern BOOL verifyEmbeddedSignature();
+extern void verifyEmbeddedSignature();
 
 extern int exceptionFilterFunction(PEXCEPTION_POINTERS exceptionPointers);
 BOOL extern elevateThis(int argc, TCHAR **argv);
@@ -969,6 +973,20 @@ extern void wrapperStopProcess(int exitCode, int force);
  */
 extern const TCHAR *wrapperGetRestartProcessMessage();
 
+/**
+ * Depending on the current state, we want to change the exact message displayed when pausing the Wrapper.
+ *
+ * The logic here needs to match that in wrapperPauseProcess.
+ */
+extern const TCHAR *wrapperGetPauseProcessMessage();
+
+/**
+ * Depending on the current state, we want to change the exact message displayed when resuming the Wrapper.
+ *
+ * The logic here needs to match that in wrapperResumeProcess.
+ */
+extern const TCHAR *wrapperGetResumeProcessMessage();
+
 /**
  * Used to ask the state engine to shut down the JVM.
  */
