@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2014 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2017 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -11,7 +11,7 @@
 
 /**
  * Author:
- *   Leif Mortenson <leif@tanukisoftware.com>
+ *   Tanuki Software Development Team <support@tanukisoftware.com>
  */
 
 #ifndef _WRAPPER_FILE_H
@@ -19,34 +19,29 @@
 
 #ifdef WIN32
 #include <tchar.h>
-#else
-#include "wrapper_i18n.h"
 #endif
+#include "property.h"
+#include "wrapper_i18n.h"
+#include "wrapper_hashmap.h"
 
 /*#define WRAPPER_FILE_DEBUG*/
 
-#define WRAPPER_FILE_SORT_MODE_TIMES 100
-#define WRAPPER_FILE_SORT_MODE_NAMES_ASC 101
-#define WRAPPER_FILE_SORT_MODE_NAMES_DEC 102
-
 /**
- * Returns a valid sort mode given a name: "TIMES", "NAMES_ASC", "NAMES_DEC".
- *  In the event of an invalid value, TIMES will be returned.
+ * Callback declaration which can be passed to calls to configFileReader.
  */
-extern int wrapperFileGetSortMode(const TCHAR *modeName);
+typedef int (*ConfigFileReader_Callback)(void *param, const TCHAR *fileName, int lineNumber, TCHAR *config, int exitOnOverwrite, int logLevelOnOverwrite);
 
-/**
- * Returns a NULL terminated list of file names within the specified pattern.
- *  The files will be sorted new to old for TIMES.  Then incremental ordering
- *  for NAMES.  The numeric components of the names will be treated as
- *  numbers and sorted accordingly.
- */
-extern TCHAR** wrapperFileGetFiles(const TCHAR* pattern, int sortMode);
-
-/**
- * Frees the array of file names returned by wrapperFileGetFiles()
- */
-extern void wrapperFileFreeFiles(TCHAR** files);
+/* Structure used by configFileReader to read files. */
+typedef struct ConfigFileReader ConfigFileReader;
+struct ConfigFileReader {
+    ConfigFileReader_Callback callback;
+    void *callbackParam;
+    int enableIncludes;
+    int preload;
+    int debugIncludes;                  /* debugIncludes controls whether or not debug output is logged. It is set using directives in the file being read. */
+    int exitOnOverwrite;                /* If TRUE, causes the wrapper to exit when any property is overwritten in the config files. */
+    int logLevelOnOverwrite;            /* Defines the log level of the messages reported when properties are overwritten. */
+};
 
 /**
  * Tests whether a file exists.
@@ -63,11 +58,6 @@ extern int wrapperGetUNCFilePath(const TCHAR *path, int advice);
 extern void wrapperFileTests();
 #endif
 
-/**
- * Callback declaration which can be passed to calls to configFileReader.
- */
-typedef int (*ConfigFileReader_Callback)(void *param, const TCHAR *fileName, int lineNumber, TCHAR *config, int debugProperties);
-
 #define CONFIG_FILE_READER_SUCCESS   101
 #define CONFIG_FILE_READER_FAIL      102
 #define CONFIG_FILE_READER_HARD_FAIL 103
@@ -84,6 +74,12 @@ typedef int (*ConfigFileReader_Callback)(void *param, const TCHAR *fileName, int
  * @param enableIncludes If TRUE then includes will be supported.
  * @param preload TRUE if this is being called in the preload step meaning that all errors
  *                should be suppressed.
+ * @param argCommand Argument passed to the binary.
+ * @param originalWorkingDir Working directory of the binary at the moment it was launched.
+ * @param warnedVarMap Map of undefined environment variables for which the user was warned.
+ * @param logWarnings Flag that controls whether or not warnings will be logged.
+ * @param logWarningLogLevel Log level at which any log warnings will be logged.
+ * @param isDebugging Flag that controls whether or not debug output will be logged.
  *
  * @return CONFIG_FILE_READER_SUCCESS if the file was read successfully,
  *         CONFIG_FILE_READER_FAIL if there were any problems at all, or
@@ -94,7 +90,13 @@ extern int configFileReader(const TCHAR *filename,
                             ConfigFileReader_Callback callback,
                             void *callbackParam,
                             int enableIncludes,
-                            int preload);
+                            int preload,
+                            const TCHAR *argCommand,
+                            const TCHAR *originalWorkingDir,
+                            PHashMap warnedVarMap,
+                            int logWarnings,
+                            int logWarningLogLevel,
+                            int isDebugging);
 
 #endif
 
