@@ -1,7 +1,7 @@
 package org.tanukisoftware.wrapper;
 
 /*
- * Copyright (c) 1999, 2011 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2017 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -19,7 +19,7 @@ import java.io.OutputStream;
  * A WrapperProcess is returned by a call to WrapperManager.exec and can
  *  be used to reference the new child process after it was launched.
  *
- * @author Leif Mortenson <leif@tanukisoftware.com>
+ * @author Tanuki Software Development Team &lt;support@tanukisoftware.com&gt;
  * @since Wrapper 3.4.0
  */
 public class WrapperProcess
@@ -90,6 +90,8 @@ public class WrapperProcess
      *  from the standard output stream of the process represented by this
      *  WrapperProcess object.
      * <p>
+     * This is an alias of the getStdOut() method.
+     * <p>
      * Implementation note: It is a good idea for the input stream to be
      *  buffered.
      * 
@@ -104,11 +106,34 @@ public class WrapperProcess
         return m_wpos;
     }
 
+    /**
+     * Gets the input stream of the subprocess. The stream obtains data piped
+     *  from the standard output stream of the process represented by this
+     *  WrapperProcess object.
+     * <p>
+     * This is an alias of the getInputStream() method.
+     * <p>
+     * Implementation note: It is a good idea for the input stream to be
+     *  buffered.
+     * 
+     * @return The input stream connected to the normal output of the
+     *         subprocess.
+     *
+     * @throws IOException If we are unable to access the stream.
+     */
+    public InputStream getStdOut()
+        throws IOException
+    {
+        return m_wpos;
+    }
+
     /**
      * Gets the error stream of the subprocess. The stream obtains data piped
      *  from the error output stream of the process represented by this
      *  WrapperProcess object.
      * <p>
+     * This is an alias of the getStdErr() method.
+     * <p>
      * Implementation note: It is a good idea for the input stream to be
      *  buffered.
      * 
@@ -123,11 +148,34 @@ public class WrapperProcess
         return m_wpes;
     }
 
+    /**
+     * Gets the error stream of the subprocess. The stream obtains data piped
+     *  from the error output stream of the process represented by this
+     *  WrapperProcess object.
+     * <p>
+     * This is an alias of the getErrorStream() method.
+     * <p>
+     * Implementation note: It is a good idea for the input stream to be
+     *  buffered.
+     * 
+     * @return The input stream connected to the error stream of the
+     *         subprocess.
+     *
+     * @throws IOException If we are unable to access the stream.
+     */
+    public InputStream getStdErr()
+        throws IOException
+    {
+        return m_wpes;
+    }
+
     /**
      * Gets the output stream of the subprocess. Output to the stream is piped
      *  into the standard input stream of the process represented by this
      *  WrapperProcess object.
      * <p>
+     * This is an alias of the getStdIn() method.
+     * <p>
      * Implementation note: It is a good idea for the output stream to be
      *  buffered.
      * 
@@ -142,6 +190,26 @@ public class WrapperProcess
         return m_wpis;
     }
 
+    /**
+     * Gets the output stream of the subprocess. Output to the stream is piped
+     *  into the standard input stream of the process represented by this
+     *  WrapperProcess object.
+     * <p>
+     * This is an alias of the getOutputStream() method.
+     * <p>
+     * Implementation note: It is a good idea for the output stream to be
+     *  buffered.
+     * 
+     * @return The output stream connected to the normal input of the
+     *         subprocess.
+     *
+     * @throws IOException If we are unable to access the stream.
+     */
+    public OutputStream getStdIn()
+        throws IOException
+    {
+        return m_wpis;
+    }
 
     /**
      * Causes the current thread to wait, if necessary, until the process
@@ -161,14 +229,12 @@ public class WrapperProcess
     public int waitFor()
         throws InterruptedException
     {
-        synchronized( this )
+        if ( m_exitcode == Integer.MIN_VALUE )
         {
-            if ( m_exitcode == Integer.MIN_VALUE )
-            {
-                nativeWaitFor();
-            }
-            return m_exitcode;
+            nativeWaitFor();
         }
+        
+        return m_exitcode;
     }
 
     /**
@@ -205,6 +271,7 @@ public class WrapperProcess
     /**
      * Kills the subprocess. The subprocess represented by this Process object
      *  is forcibly terminated if it is still running.
+     *
      * @throws WrapperLicenseError If the function is called other than in
      *                             the Professional Edition or from a Standalone JVM.
      */
