@@ -1,7 +1,7 @@
 package org.tanukisoftware.wrapper.test;
 
 /*
- * Copyright (c) 1999, 2014 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2017 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -46,7 +46,7 @@ import org.tanukisoftware.wrapper.event.WrapperEvent;
 import org.tanukisoftware.wrapper.event.WrapperEventListener;
 
 /**
- * @author Leif Mortenson <leif@tanukisoftware.com>
+ * @author Tanuki Software Development Team &lt;support@tanukisoftware.com&gt;
  */
 public abstract class AbstractActionApp
     implements WrapperEventListener
@@ -196,6 +196,13 @@ public abstract class AbstractActionApp
         m_err = new DeadlockPrintStream( System.err );
         System.setErr( m_err );
     }
+    
+    protected void updateEventListener()
+    {
+        WrapperManager.removeWrapperEventListener( this );
+        WrapperManager.addWrapperEventListener( this, m_eventMask );
+    }
+    
     protected boolean doAction( String action )
     {
         if ( action.equals( "stop0" ) )
@@ -317,7 +324,7 @@ public abstract class AbstractActionApp
         }
         else if ( action.equals( "deadlock_out" ) )
         {
-            System.out.println( Main.getRes().getString( "Deadlocking System.out and System.err ..." ) );
+            System.out.println( Main.getRes().getString( "Deadlocking System.out and System.err..." ) );
             m_out.setDeadlock( true );
             m_err.setDeadlock( true );
             
@@ -381,7 +388,7 @@ public abstract class AbstractActionApp
                             try
                             {
                                 do {
-                                    System.out.println( Main.getRes().getString( "Input an action ('help' for a list of actions):") );
+                                    System.out.println( Main.getRes().getString( "Input an action (''help'' for a list of actions):") );
                                     line = r.readLine();
                                     if ((line != null) && (!line.equals(""))) {
                                         System.out.println(Main.getRes().getString( "Read action: {0}", line ) );
@@ -453,8 +460,7 @@ public abstract class AbstractActionApp
         else if ( action.equals( "listener" ) )
         {
             System.out.println( Main.getRes().getString( "Updating Event Listeners:" ) );
-            WrapperManager.removeWrapperEventListener( this );
-            WrapperManager.addWrapperEventListener( this, m_eventMask );
+            updateEventListener();
         }
         else if ( action.equals( "service_list" ) )
         {
@@ -639,25 +645,25 @@ public abstract class AbstractActionApp
             {
                 processConfig.setStartType( WrapperProcessConfig.FORK_EXEC );
                 type = "FORK_EXEC";
-                command.substring( 10 );
+                command = command.substring( 10 );
             }
             else if ( command.startsWith( "POSIX_SPAWN " ) )
             {
                 processConfig.setStartType( WrapperProcessConfig.POSIX_SPAWN );
                 type = "POSIX_SPAWN";
-                command.substring( 12 );
+                command = command.substring( 12 );
             }
             else if ( command.startsWith( "VFORK_EXEC " ) )
             {
                 processConfig.setStartType( WrapperProcessConfig.VFORK_EXEC );
                 type = "VFORK_EXEC";
-                command.substring( 11 );
+                command = command.substring( 11 );
             }
             else if ( command.startsWith( "DYNAMIC " ) )
             {
                 processConfig.setStartType( WrapperProcessConfig.DYNAMIC );
                 type = "DYNAMIC";
-                command.substring( 8 );
+                command = command.substring( 8 );
             }
             else
             {
@@ -741,7 +747,7 @@ public abstract class AbstractActionApp
         System.err.println( Main.getRes().getString( "   outofmemory              : Simulates an OutOfMemoryError being thrown" ) );
         System.err.println( Main.getRes().getString( "   ignore_events            : Makes this application ignore control events." ) );
         System.err.println( Main.getRes().getString( "   dump                     : Calls WrapperManager.requestThreadDump()" ) );
-        System.err.println( Main.getRes().getString( "   deadlock_out             : Deadlocks the JVM's System.out and err streams." ) );
+        System.err.println( Main.getRes().getString( "   deadlock_out             : Deadlocks the JVM''s System.out and err streams." ) );
         System.err.println( Main.getRes().getString( "   users                    : Start polling the current and interactive users." ) );
         System.err.println( Main.getRes().getString( "   groups                   : Start polling the current and interactive users with groups." ) );
         System.err.println( Main.getRes().getString( "   console                  : Prompt for actions in the console." ) );
